@@ -1,8 +1,8 @@
 from .IRoof import IRoof
-from .IAltAz import IAltAz
+from .IPointingAltAz import IPointingAltAz
 
 
-class IDome(IRoof, IAltAz):
+class IDome(IRoof, IPointingAltAz):
     """The module controls a dome, i.e. a :class:`~pyobs.interfaces.IRoof` with a rotating roof."""
     __module__ = 'pyobs.interfaces'
     pass
