@@ -1,14 +1,14 @@
-from typing import List
+from typing import List, Any
 
 from .interface import Interface
-from ..utils.enums import ImageFormat
+from pyobs.utils.enums import ImageFormat
 
 
 class IImageFormat(Interface):
     """The module supports different image formats (e.g. INT16, FLOAT32), mainly used by cameras."""
     __module__ = 'pyobs.interfaces'
 
-    def set_image_format(self, format: ImageFormat, *args, **kwargs):
+    def set_image_format(self, format: ImageFormat, **kwargs: Any) -> None:
         """Set the camera image format.
 
         Args:
@@ -19,7 +19,7 @@ class IImageFormat(Interface):
         """
         raise NotImplementedError
 
-    def get_image_format(self, *args, **kwargs) -> ImageFormat:
+    def get_image_format(self, **kwargs: Any) -> ImageFormat:
         """Returns the camera image format.
 
         Returns:
@@ -27,7 +27,7 @@ class IImageFormat(Interface):
         """
         raise NotImplementedError
 
-    def list_image_formats(self, *args, **kwargs) -> List[str]:
+    def list_image_formats(self, **kwargs: Any) -> List[str]:
         """List available image formats.
 
         Returns:
