@@ -1,3 +1,5 @@
+from typing import Any
+
 from .IMotion import IMotion
 
 
@@ -5,7 +7,7 @@ class IRotation(IMotion):
     """The module controls a device that can rotate."""
     __module__ = 'pyobs.interfaces'
 
-    def set_rotation(self, angle, *args, **kwargs):
+    def set_rotation(self, angle: float, **kwargs: Any) -> None:
         """ Sets the rotation angle to the given value in degrees. """
         raise NotImplementedError
 
@@ -13,7 +15,7 @@ class IRotation(IMotion):
         """ Returns the current rotation angle. """
         raise NotImplementedError
 
-    def track(self, ra: float, dec: float, *args, **kwargs):
+    def track(self, ra: float, dec: float, **kwargs: Any) -> None:
         """ Tracks the position angle of a rotator for an alt-az telescope. """
         raise NotImplementedError
 
