@@ -1,3 +1,5 @@
+from typing import Any
+
 from .IAbortable import IAbortable
 
 
@@ -5,7 +7,7 @@ class IRunnable(IAbortable):
     """The module has some action that can be started remotely."""
     __module__ = 'pyobs.interfaces'
 
-    def run(self, *args, **kwargs):
+    def run(self, **kwargs: Any) -> None:
         """Perform module task"""
         raise NotImplementedError
 
