@@ -1,7 +1,7 @@
 import logging
-from typing import List, Dict, Tuple, Any
+from typing import List, Dict, Tuple, Any, Optional
 
-from pyobs.interfaces import IRoof, IFitsHeaderProvider
+from pyobs.interfaces import IRoof, IFitsHeaderBefore
 from pyobs.modules import Module
 from pyobs.mixins import MotionStatusMixin, WeatherAwareMixin
 from pyobs.utils.enums import MotionStatus
@@ -9,19 +9,19 @@ from pyobs.utils.enums import MotionStatus
 log = logging.getLogger(__name__)
 
 
-class BaseRoof(WeatherAwareMixin, MotionStatusMixin, IRoof, IFitsHeaderProvider, Module):
+class BaseRoof(WeatherAwareMixin, MotionStatusMixin, IRoof, IFitsHeaderBefore, Module):
     """Base class for roofs."""
     __module__ = 'pyobs.modules.roof'
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, **kwargs: Any):
         """Initialize a new base roof."""
-        Module.__init__(self, *args, **kwargs)
+        Module.__init__(self, **kwargs)
 
         # init mixins
-        WeatherAwareMixin.__init__(self, *args, **kwargs)
-        MotionStatusMixin.__init__(self, *args, **kwargs)
+        WeatherAwareMixin.__init__(self, **kwargs)
+        MotionStatusMixin.__init__(self, **kwargs)
 
-    def open(self):
+    def open(self) -> None:
         """Open module."""
         Module.open(self)
 
@@ -29,7 +29,7 @@ class BaseRoof(WeatherAwareMixin, MotionStatusMixin, IRoof, IFitsHeaderProvider,
         WeatherAwareMixin.open(self)
         MotionStatusMixin.open(self)
 
-    def get_fits_headers(self, namespaces: List[str] = None, *args, **kwargs) -> Dict[str, Tuple[Any, str]]:
+    def get_fits_header_before(self, namespaces: Optional[List[str]] = None, **kwargs: Any) -> Dict[str, Tuple[Any, str]]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -43,7 +43,7 @@ class BaseRoof(WeatherAwareMixin, MotionStatusMixin, IRoof, IFitsHeaderProvider,
                          'True for open, false for closed roof')
         }
 
-    def is_ready(self, *args, **kwargs) -> bool:
+    def is_ready(self, **kwargs: Any) -> bool:
         """Returns the device is "ready", whatever that means for the specific device.
 
         Returns:
