@@ -1,4 +1,5 @@
 import logging
+from typing import Any, List, Dict
 
 from pyobs.events import Event
 from pyobs.modules import Module
@@ -12,7 +13,7 @@ class Trigger(Module, IAutonomous):
     """A module that can call another module's methods when a specific event occurs."""
     __module__ = 'pyobs.modules.utils'
 
-    def __init__(self, triggers: list, *args, **kwargs):
+    def __init__(self, triggers: List[Dict[str, Any]], **kwargs: Any):
         """Initialize a new trigger module.
 
         Args:
@@ -20,7 +21,7 @@ class Trigger(Module, IAutonomous):
                       may contain a sender.
 
         """
-        Module.__init__(self, *args, **kwargs)
+        Module.__init__(self, **kwargs)
 
         # store
         self._running = False
@@ -32,7 +33,7 @@ class Trigger(Module, IAutonomous):
             kls = get_class_from_string(trigger['event'])
             trigger['event'] = kls
 
-    def open(self):
+    def open(self) -> None:
         """Open module."""
         Module.open(self)
 
@@ -46,19 +47,19 @@ class Trigger(Module, IAutonomous):
         for event in events:
             self.comm.register_event(event, self._handle_event)
 
-    def start(self, *args, **kwargs):
+    def start(self, **kwargs: Any) -> None:
         """Starts a service."""
         self._running = True
 
-    def stop(self, *args, **kwargs):
+    def stop(self, **kwargs: Any) -> None:
         """Stops a service."""
         self._running = False
 
-    def is_running(self, *args, **kwargs) -> bool:
+    def is_running(self, **kwargs: Any) -> bool:
         """Whether a service is running."""
         return self._running
 
-    def _handle_event(self, event: Event, sender: str):
+    def _handle_event(self, event: Event, sender: str) -> bool:
         """Handle an incoming event.
 
         Args:
@@ -68,7 +69,7 @@ class Trigger(Module, IAutonomous):
 
         # not running?
         if not self._running:
-            return
+            return False
 
         # loop all triggers
         for trigger in self._triggers:
@@ -79,17 +80,20 @@ class Trigger(Module, IAutonomous):
 
                 # get proxy
                 try:
-                    proxy = self.comm[trigger['module']]
-                except KeyError:
-                    log.error('Could not get proxy for %s.', trigger['module'])
+                    proxy = self.comm.proxy(trigger['module'])
+
+                    # call it
+                    proxy.execute(trigger['method'])
+
+                except ValueError:
+                    log.exception('Could not execute command on proxy %s.', trigger['module'])
                     continue
 
-                # call it
-                try:
-                    proxy.execute(trigger['method'])
                 except Exception as e:
                     log.error('Error on calling %s.%s: %s', trigger['module'], trigger['method'], e)
                     continue
 
+        return True
+
 
 __all__ = ['Trigger']
