@@ -1,11 +1,9 @@
 import logging
 import threading
-from typing import Any, Type, Union, TypeVar, Optional
-
+from typing import Any, TypeVar, Optional, List, Dict
 from astroplan import Observer
 
 from pyobs.comm import Comm
-from pyobs.comm.proxy import Proxy
 from pyobs.robotic import TaskArchive
 
 log = logging.getLogger(__name__)
@@ -15,14 +13,14 @@ ProxyClass = TypeVar('ProxyClass')
 
 
 class Script:
-    def __init__(self, configuration: Any, task_archive: TaskArchive, comm: Comm, observer: Observer, *args, **kwargs):
+    def __init__(self, configuration: Any, task_archive: TaskArchive, comm: Comm, observer: Observer, **kwargs: Any):
         """Init Script.
 
         Args:
             comm: Comm object to use
             observer: Observer to use
         """
-        self.exptime_done = 0
+        self.exptime_done: float = 0.
         self.configuration = configuration
         self.task_archive = task_archive
         self.comm = comm
@@ -32,7 +30,7 @@ class Script:
         """Whether this config can currently run."""
         raise NotImplementedError
 
-    def run(self, abort_event: threading.Event):
+    def run(self, abort_event: threading.Event) -> None:
         """Run script.
 
         Args:
@@ -43,7 +41,7 @@ class Script:
         """
         raise NotImplementedError
 
-    def _check_abort(self, abort_event: threading.Event):
+    def _check_abort(self, abort_event: threading.Event) -> None:
         """Check, whether we can continue with script.
 
         Args:
@@ -56,7 +54,7 @@ class Script:
         if abort_event.is_set() or not self.can_run():
             raise InterruptedError
 
-    def get_fits_headers(self, namespaces: list = None) -> dict:
+    def get_fits_headers(self, namespaces: Optional[List[str]] = None) -> Dict[str, Any]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -67,26 +65,5 @@ class Script:
         """
         return {}
 
-    def _get_proxy(self, name: str, proxy_class: Type[ProxyClass]) -> Optional[ProxyClass]:
-        """Returns a single proxy.
-
-        Args:
-            name: Name of proxy
-            proxy_class: Expected class of proxy
-
-        Returns:
-            Proxy or None on errors
-        """
-
-        # nothing?
-        if name is None:
-            return None
-
-        # try to get proxy
-        try:
-            return self.comm.proxy(name, proxy_class)
-        except ValueError:
-            return None
-
 
 __all__ = ['Script']
