@@ -1,3 +1,5 @@
+from typing import Dict, Tuple, Any
+
 from .base import SkyflatPriorities
 
 
@@ -5,11 +7,11 @@ class ConstSkyflatPriorities(SkyflatPriorities):
     """Constant flat priorities."""
     __module__ = 'pyobs.utils.skyflats.priorities'
 
-    def __init__(self, priorities: dict, *args, **kwargs):
+    def __init__(self, priorities: Dict[Tuple[str, Tuple[int, int]], float], *args: Any, **kwargs: Any):
         SkyflatPriorities.__init__(self)
         self._priorities = priorities
 
-    def __call__(self):
+    def __call__(self) -> Dict[Tuple[str, Tuple[int, int]], float]:
         return self._priorities
 
 
