@@ -1,5 +1,6 @@
 import logging
-
+import threading
+from typing import Any, Union
 
 log = logging.getLogger(__name__)
 
@@ -10,12 +11,12 @@ class AcquireLockFailed(Exception):
 
 class LockWithAbort(object):
     """Tries to acquire a lock. If unsuccessful, it sets the event and tries again."""
-    def __init__(self, lock, event):
+    def __init__(self, lock: Union[threading.Lock, threading.RLock], event: threading.Event):
         self.lock = lock
         self.event = event
         self.acquired = False
 
-    def __enter__(self):
+    def __enter__(self) -> None:
         # first try to acquire lock without timeout
         self.acquired = self.lock.acquire(timeout=0.)
 
@@ -35,7 +36,7 @@ class LockWithAbort(object):
         # got lock, so unset abort and remember that we were successful
         self.event.clear()
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
         # if we acquired the lock, we release it again here
         if self.acquired:
             self.lock.release()
